@@ -171,7 +171,30 @@ int xlatekey(void)
 	
       case XK_KP_Subtract:
       case XK_minus:	rc = KEY_MINUS;		break;
-	
+
+      case XK_KP_0:    rc = '0';               break;
+      case XK_KP_1:    rc = '1';               break;
+      case XK_KP_2:    rc = '2';               break;
+      case XK_KP_3:    rc = '3';               break;
+      case XK_KP_4:    rc = '4';               break;
+      case XK_KP_5:    rc = '5';               break;
+      case XK_KP_6:    rc = '6';               break;
+      case XK_KP_7:    rc = '7';               break;
+      case XK_KP_8:    rc = '8';               break;
+      case XK_KP_9:    rc = '9';               break;
+
+      /* This is an ugly PC-ism. Better switch to XLookupKeysym() ? */
+      case XK_KP_Insert:       rc = '0';       break;
+      case XK_KP_End:          rc = '1';       break;
+      case XK_KP_Down:         rc = '2';       break;
+      case XK_KP_Page_Down:    rc = '3';       break;
+      case XK_KP_Left:         rc = '4';       break;
+      case XK_KP_Begin:                rc = '5';       break;
+      case XK_KP_Right:                rc = '6';       break;
+      case XK_KP_Home:         rc = '7';       break;
+      case XK_KP_Up:           rc = '8';       break;
+      case XK_KP_Page_Up:      rc = '9';       break;
+
       case XK_Shift_L:
       case XK_Shift_R:
 	rc = KEY_RSHIFT;
